@@ -1,2 +1,2 @@
 from run_all_the_tests.test_case import TestCasePath, Group, TestType, TestCase
-from run_all_the_tests.run_all_the_tests import run_all_tests
+from run_all_the_tests.test_runner import run_all_tests
