@@ -103,7 +103,7 @@ def _get_group_tests(
 
 
 def run_all_tests(test_cases: Tuple[TestCase, ...] = tuple()) -> None:
-    run_all_tests_start: str = "TIME BRACKET"
+    run_all_tests_start: str = "TIME_BRACKET"
     running_test_cases: List[_RunningTestCase] = []
     test_count: int = 0
     tests_passed: int = 0
@@ -144,13 +144,13 @@ def run_all_tests(test_cases: Tuple[TestCase, ...] = tuple()) -> None:
         running_test_cases.clear()
 
     # pylint: disable=pointless-string-statement
-    "TIME BRACKET"
+    "TIME_BRACKET"
     # pylint: enable=pointless-string-statement
 
     elapsed_time: timeit.Timer = timeit.timeit(run_all_tests_start)
     if tests_passed == test_count:
-        print(f"\nAll {test_count} tests passed! ({elapsed_time.timeit()})")
+        print(f"\nAll {test_count} tests passed! ({elapsed_time})")
     else:
         print(
-            f"\n{tests_passed} tests out of {test_count} passed ({elapsed_time.timeit()})"
+            f"\n{tests_passed} tests out of {test_count} passed ({elapsed_time})"
         )
